# Enlighten Me

[![Build Status](https://travis-ci.com/singhgarima/enlightenme.svg?branch=master)](https://travis-ci.com/singhgarima/enlightenme)

A simple python CLI for curating and reading news/updates from your favorite
channels.

## Installation

```bash
pip install enlightenme
```

## Getting Started

* Getting help

<a href="https://asciinema.org/a/wyubbW3B6KsOI4Gi5uBDMfJFf" target="_blank"><img src="https://asciinema.org/a/wyubbW3B6KsOI4Gi5uBDMfJFf.png" align="center" width="600"/></a>

* Hacker News Sample

<a href="https://asciinema.org/a/X8a922jbNjvpm4NZfKnmuCM94" target="_blank"><img src="https://asciinema.org/a/X8a922jbNjvpm4NZfKnmuCM94.png" align="center" width="600"/></a>

* Reddit Sample

<a href="https://asciinema.org/a/0aalvvZ8PBjCzOY6yBAMXBlBh" target="_blank"><img src="https://asciinema.org/a/0aalvvZ8PBjCzOY6yBAMXBlBh.png" align="center" width="600"/></a>